Functin calculates the probability for intermittent state space model. This is needed in order to forecast intermittent demand using other functions.
iss(data, intermittent = c("none", "fixed", "croston", "tsb", "sba"),
h = 10, holdout = FALSE, model = NULL, persistence = NULL)Either numeric vector or time series vector.
Type of method used in probability estimation. Can be
"none" - none, "fixed" - constant probability,
"croston" - estimated using Croston, 1972 method and "TSB" -
Teunter et al., 2011 method., "sba" - Syntetos-Boylan Approximation
for Croston's method (bias correction) discussed in Syntetos and Boylan,
2005.
Forecast horizon.
If TRUE, holdout sample of size h is taken from
the end of the data.
Type of ETS model used for the estimation. Normally this should
be either "ANN" or "MNN".
Persistence vector. If NULL, then it is estimated.
The object of class "iss" is returned. It contains following list of values:
fitted - fitted values of the constructed model;
states - values of states (currently level only);
forecast - forecast for h observations ahead;
variance - conditional variance of the forecast;
logLik - likelihood value for the model
nParam - number of parameters used in the model;
residuals - residuals of the model;
C - vector of all the parameters.
actuals - actual values of probabilities (zeroes and ones).
The function estimates probability of demand occurance, using one of the ETS state-space models.
Teunter R., Syntetos A., Babai Z. (2011). Intermittent demand: Linking forecasting to inventory obsolescence. European Journal of Operational Research, 214, 606-615.
Croston, J. (1972) Forecasting and stock control for intermittent demands. Operational Research Quarterly, 23(3), 289-303.
Syntetos, A., Boylan J. (2005) The accuracy of intermittent demand estimates. International Journal of Forecasting, 21(2), 303-314.
y <- rpois(100,0.1)
iss(y, intermittent="t")
iss(y, intermittent="c", persistence=0.1)
Run the code above in your browser using DataLab