Learn R Programming

smooth (version 1.4.3)

smooth: Smooth package

Description

Package contains several exponential (and not) smoothing functions used in time series analysis and forecasting.

Arguments

Details

Package:
smooth
Type:
Package
Date:
2016-01-27 - Inf
License:
GPL-2
The following functions are included in the package:
  • es - Exponential Smoothing in Single Source of Errors State Space form.
  • ces - Complex Exponential Smoothing.
  • ges - Generalised Exponential Smoothing.
  • ssarima - SARIMA in state-space framework.

  • auto.ces - Automatic selection between seasonal and non-seasonal CES.
  • auto.ssarima - Automatic selection of ARIMA orders.
  • sma - Simple Moving Average in state-space form.

  • sim.es - simulate time series using ETS as a model.
  • iss - intermittent data state-space model. This function models the part with data occurances using one of three methods.

References

  • Croston, J. (1972) Forecasting and stock control for intermittent demands. Operational Research Quarterly, 23(3), 289-303.
  • Hyndman, R.J., Koehler, A.B., Ord, J.K., and Snyder, R.D. (2008) Forecasting with exponential smoothing: the state space approach, Springer-Verlag. http://www.exponentialsmoothing.net.
  • Kolassa, S. (2011) Combining exponential smoothing forecasts using Akaike weights. International Journal of Forecasting, 27, pp 238 - 251.
  • Svetunkov, I., Kourentzes, N. (February 2015). Complex exponential smoothing. Working Paper of Department of Management Science, Lancaster University 2015:1, 1-31.
  • Svetunkov I., Kourentzes N. (2016) Complex Exponential Smoothing for Time Series Forecasting. Not yet published.
  • Svetunkov I., Kourentzes N. (2016) Trace forecast likelihood and shrinkage in time series models. Not yet published.
  • Svetunkov S. (2012) Complex-Valued Modeling in Economics and Finance. SpringerLink: Bucher. Springer.
  • Taylor, J.W. and Bunn, D.W. (1999) A Quantile Regression Approach to Generating Prediction Intervals. Management Science, Vol 45, No 2, pp 225-237.
  • Teunter R., Syntetos A., Babai Z. (2011). Intermittent demand: Linking forecasting to inventory obsolescence. European Journal of Operational Research, 214, 606-615.

See Also

forecast

Examples

Run this code
## Not run: y <- ts(rnorm(100,10,3),frequency=12)
# 
# es(y,h=20,holdout=TRUE)
# ges(y,h=20,holdout=TRUE)
# auto.ces(y,h=20,holdout=TRUE)
# auto.ssarima(y,h=20,holdout=TRUE)## End(Not run)

Run the code above in your browser using DataLab