| om | R Documentation |
Function returns the occurrence part of the ADAM model with the specified probability update and model types.
om(data, model = "ZXZ", lags = c(frequency(data)), orders = list(ar =
c(0), i = c(0), ma = c(0), select = FALSE), constant = FALSE,
formula = NULL, regressors = c("use", "select", "adapt"),
occurrence = c("auto", "fixed", "odds-ratio", "inverse-odds-ratio",
"direct", "general"), loss = c("likelihood", "MSE", "MAE", "HAM", "LASSO",
"RIDGE"), h = 0, holdout = FALSE, persistence = NULL, phi = NULL,
initial = c("backcasting", "optimal", "two-stage", "complete"),
arma = NULL, ic = c("AICc", "AIC", "BIC", "BICc"), bounds = c("usual",
"admissible", "none"), ets = c("conventional", "adam"), silent = TRUE,
...)
data |
Numeric vector, time series, or data frame. Non-binary input is automatically binarised: any non-zero value becomes 1. |
model |
Three-letter ETS specification such as |
lags |
Vector of seasonal lags. Defaults to |
orders |
ARIMA orders list: |
constant |
Logical; whether to include a constant term. |
formula |
Optional formula for external regressors. |
regressors |
How to handle regressors: |
occurrence |
Type of link function mapping state to probability:
|
loss |
Loss function: |
h |
Forecast horizon. |
holdout |
If |
persistence |
Optional persistence (smoothing) parameter vector. |
phi |
Optional damping parameter. |
initial |
Initialisation method: |
arma |
Optional fixed ARMA parameters. |
ic |
Information criterion for model selection. |
bounds |
Parameter bounds type. |
ets |
Type of ETS model: |
silent |
If |
... |
Additional arguments passed to the optimiser ( |
The function estimates probability of demand occurrence, using the selected ADAM state space model. It supports ETS, ARIMA and explanatory variables, also allowing to have multiple frequencies and doing variables selection. It is an ADAM analogue for the binary occurrence variable modelling.
For the details about the model and its implementation, see the respective
vignette: vignette("om","smooth")
An object of class c("om","adam","smooth").
forecast.om, adam
set.seed(42)
y <- rbinom(120, 1, 0.6)
m <- om(y, model="MNN", occurrence="odds-ratio")
forecast(m, h=12)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.